formattools.report_spanner_format_contributions
===============================================

.. autofunction:: abjad.tools.formattools.report_spanner_format_contributions.report_spanner_format_contributions
   :noindex:
